@@ -44,7 +44,7 @@ def get_scoring_name(scoring):
 
 class EvaluationPool:
 
-    def __init__(self, X, y, scoring, side_scores = None, tolerance_tuning = 0.05, tolerance_estimation_error = 0.01, logger_name = None):
+    def __init__(self, X, y, scoring, evaluation_fun = None, side_scores = None, tolerance_tuning = 0.05, tolerance_estimation_error = 0.01, logger_name = None):
         self.logger = logging.getLogger('naiveautoml.evalpool' if logger_name is None else logger_name)
         if X is None:
             raise Exception("Parameter X must not be None")
@@ -66,6 +66,7 @@ class EvaluationPool:
         self.tolerance_tuning = tolerance_tuning
         self.tolerance_estimation_error = tolerance_estimation_error
         self.cache = {}
+        self.evaluation_fun = self.cross_validate if evaluation_fun is None else evaluation_fun
 
     def tellEvaluation(self, pl, scores, timestamp):
         spl = str(pl)
@@ -128,12 +129,14 @@ class EvaluationPool:
             return out
         timestamp = time.time()
         if timeout is not None:
-            scores = func_timeout(timeout, self.cross_validate, (pl, self.X, self.y, [self.scoring] + self.side_scores))
+            scores = func_timeout(timeout, self.evaluation_fun, (pl, self.X, self.y, [self.scoring] + self.side_scores))
         else:
-            scores = self.cross_validate(pl, self.X, self.y, [self.scoring] + self.side_scores)
+            scores = self.evaluation_fun(pl, self.X, self.y, [self.scoring] + self.side_scores)
         if scores is None:
             return {get_scoring_name(scoring): np.nan for scoring in [self.scoring] + self.side_scores}
         runtime = time.time() - start_outer
+        if type(scores) != dict:
+            raise ValueError(f"scores is of type {type(scores)} but must be a dictionary with entries for {get_scoring_name(self.scoring)}.\nProbably you inserted an evaluation_fun argument that does not return a proper dictionary.")
         self.logger.info(f"Completed evaluation of {spl} after {runtime}s. Scores are {scores}")
         self.tellEvaluation(pl, scores[get_scoring_name(self.scoring)], timestamp)
         return {scoring: np.round(np.mean(scores[scoring]), 4) for scoring in scores}
@@ -1002,7 +1005,7 @@ sklearn.preprocessing.PowerTransformer, "classifier": sklearn.naive_bayes.Multin
 
 class HPOProcess:
     
-    def __init__(self, step_name, comp, X, y, scoring, side_scores, execution_timeout, mandatory_pre_processing, other_step_component_instances, index_in_steps, max_time_without_imp, max_its_without_imp, min_its = 10, logger_name = None, allow_exhaustive_search = True):
+    def __init__(self, step_name, comp, X, y, scoring, side_scores, evaluation_fun, execution_timeout, mandatory_pre_processing, other_step_component_instances, index_in_steps, max_time_without_imp, max_its_without_imp, min_its = 10, logger_name = None, allow_exhaustive_search = True):
         self.step_name = step_name
         self.index_in_steps = index_in_steps
         self.comp = comp
@@ -1025,7 +1028,7 @@ class HPOProcess:
         self.max_its_without_imp = max_its_without_imp
         self.min_its = min_its
         self.scoring = scoring
-        self.pool = EvaluationPool(X, y, scoring, side_scores)
+        self.pool = EvaluationPool(X, y, scoring = scoring, side_scores = side_scores, evaluation_fun = evaluation_fun)
         self.its = 0
         self.allow_exhaustive_search = allow_exhaustive_search
         
