@@ -26,7 +26,7 @@ from naiveautoml.commons import *
 
 class NaiveAutoML:
 
-    def __init__(self, search_space = None, scoring = None, side_scores = None , num_cpus = 8, execution_timeout = 10, max_hpo_iterations = 100, timeout = None, standard_classifier=sklearn.neighbors.KNeighborsClassifier, standard_regressor = sklearn.linear_model.LinearRegression(), logger_name = None, show_progress = False, opt_ordering = None, strictly_naive=False, sparse = False, task_type = "auto"):
+    def __init__(self, search_space = None, scoring = None, side_scores = None, evaluation_fun = None, num_cpus = 8, execution_timeout = 10, max_hpo_iterations = 100, timeout = None, standard_classifier=sklearn.neighbors.KNeighborsClassifier, standard_regressor = sklearn.linear_model.LinearRegression(), logger_name = None, show_progress = False, opt_ordering = None, strictly_naive=False, sparse = False, task_type = "auto"):
         if type(search_space) == str:
             f = open(search_space)
             self.search_space = json.load(f)
@@ -35,6 +35,7 @@ class NaiveAutoML:
             
         self.scoring = scoring
         self.side_scores = side_scores
+        self.evaluation_fun = evaluation_fun
         self.num_cpus = num_cpus
         self.execution_timeout = execution_timeout
         self.max_hpo_iterations = max_hpo_iterations
@@ -90,7 +91,7 @@ class NaiveAutoML:
         
     def check_combinations(self, X, y):
         
-        pool = EvaluationPool(X, y, self.scoring, self.side_scores)
+        pool = EvaluationPool(X, y, scoring = self.scoring, side_scores = self.side_scores, evaluation_fun = self.evaluation_fun)
         algorithms_per_stage = []
         names = []
         for step in self.search_space:
@@ -192,7 +193,7 @@ class NaiveAutoML:
                 components = step["components"]
             
             # find best default parametrization for this slot (depending on choice of previously configured slots)
-            pool = EvaluationPool(X, y, self.scoring, self.side_scores, logger_name = None if self.logger_name is None else self.logger_name + ".pool")
+            pool = EvaluationPool(X, y, scoring = self.scoring, side_scores = self.side_scores, evaluation_fun = self.evaluation_fun, logger_name = None if self.logger_name is None else self.logger_name + ".pool")
             best_score = -np.inf
             decision = None
             for comp in components:
@@ -277,7 +278,23 @@ class NaiveAutoML:
             else:
                 other_instances = [(step_name, None), ("learner", self.standard_classifier())]
             index = 0 # it is (rather by coincidence) the first step we want to optimize
-            hpo = HPOProcess(step_name, comp, X, y, self.scoring, self.side_scores, self.execution_timeout, self.mandatory_pre_processing, other_instances, index, 1800, 1000, allow_exhaustive_search = (self.max_hpo_iterations is None), logger_name =  None if self.logger_name is None else self.logger_name + ".hpo")
+            hpo = HPOProcess(
+                step_name,
+                comp,
+                X,
+                y,
+                scoring = self.scoring,
+                side_scores = self.side_scores,
+                evaluation_fun = self.evaluation_fun,
+                execution_timeout = self.execution_timeout,
+                mandatory_pre_processing = self.mandatory_pre_processing,
+                other_step_component_instances = other_instances,
+                index_in_steps = index,
+                max_time_without_imp = 1800,
+                max_its_without_imp = 1000,
+                allow_exhaustive_search = (self.max_hpo_iterations is None),
+                logger_name =  None if self.logger_name is None else self.logger_name + ".hpo"
+            )
             hpo.best_score = components_with_score[step_name] # performance of default config
             hpo_processes[step_name] = hpo
         
@@ -419,7 +436,7 @@ class NaiveAutoML:
         self.logger.info(f"Runtime was {self.end_time - self.start_time} seconds")
         
     def eval_history(self, X, y):
-        pool = EvaluationPool(X, y, self.scoring, self.side_scores)
+        pool = EvaluationPool(X, y, scoring = self.scoring, side_scores = self.side_scores, evaluation_fun = self.evaluation_fun)
         scores = []
         for entry in self.history:
             scores.append(pool.evaluate(entry["pl"]))
