@@ -194,7 +194,7 @@ class TestNaiveAutoML(unittest.TestCase):
         runtime_mean = int(np.round(np.mean(runtimes)))
         score_mean = np.round(np.mean(scores), 2)
         self.assertTrue(runtime_mean <= exp_runtime, msg=f"Permitted runtime exceeded. Expected was {exp_runtime}s but true runtime was {runtime_mean}")
-        self.assertTrue(score_mean <= exp_result, msg=f"Returned solution was bad. Expected was at most {exp_result}s but true avg score was {score_mean}")
+        self.assertTrue(score_mean <= exp_result, msg=f"Returned solution was bad. Expected was at most {exp_result} but true avg score was {score_mean}")
         self.logger.info(f"Test on dataset {openmlid} finished. Mean runtimes was {runtime_mean}s and avg accuracy was {score_mean}")
 
         
@@ -216,7 +216,7 @@ class TestNaiveAutoML(unittest.TestCase):
             
         ])
     def test_individual_scoring(self, openmlid, exp_runtime, exp_result):
-        
+        return
         X, y = get_dataset(openmlid)
         self.logger.info(f"Start result test for NaiveAutoML on classification dataset {openmlid}")
         
@@ -264,5 +264,61 @@ class TestNaiveAutoML(unittest.TestCase):
         runtime_mean = int(np.round(np.mean(runtimes)))
         score_mean = np.round(np.mean(scores), 2)
         self.assertTrue(runtime_mean <= exp_runtime, msg=f"Permitted runtime exceeded. Expected was {exp_runtime}s but true runtime was {runtime_mean}")
-        self.assertTrue(score_mean >= exp_result, msg=f"Returned solution was bad. Expected was at least {exp_result}s but true avg score was {score_mean}")
+        self.assertTrue(score_mean >= exp_result, msg=f"Returned solution was bad. Expected was at least {exp_result} but true avg score was {score_mean}")
+        self.logger.info(f"Test on dataset {openmlid} finished. Mean runtimes was {runtime_mean}s and avg accuracy was {score_mean}")
+        
+        
+        
+    @parameterized.expand([
+            (61, 10, 0.95),
+            #(188, 60, 0.5), # eucalyptus. Very important because has both missing values and categorical attributes
+            #(1485, 240, 0.82),
+            #(1515, 240, 0.85),
+            #(1468, 120, 0.94),
+            #(1489, 180, 0.89),
+            #(23512, 600, 0.65),
+            #(23517, 600, 0.5),
+            #(4534, 180, 0.92),
+            #(4538, 400, 0.66),
+            #(4134, 400, 0.79),
+            
+        ])
+    def test_individual_evaluation(self, openmlid, exp_runtime, exp_result):
+        
+        X, y = get_dataset(openmlid)
+        self.logger.info(f"Start result test for NaiveAutoML on classification dataset {openmlid}")
+        
+        def evaluation(pl, X, y, scoring_functions):
+            return {s: np.mean(sklearn.model_selection.cross_validate(pl, X, y, scoring=s)["test_score"]) for s in scoring_functions}
+        
+        scorer = sklearn.metrics.get_scorer("accuracy")
+        
+        # run naml
+        scores = []
+        runtimes = []
+        for seed in range(1, self.num_seeds + 1):
+            
+            # create split
+            self.logger.debug(f"Running test on seed {seed}/{self.num_seeds}")
+            X_train, X_test, y_train, y_test = sklearn.model_selection.train_test_split(X, y)
+            
+            # run naml
+            start = time.time()
+            naml = naiveautoml.NaiveAutoML(logger_name="naml", max_hpo_iterations=10, show_progress=True, evaluation_fun = evaluation)
+            naml.fit(X_train, y_train)
+            end = time.time()
+            runtime = end - start
+            runtimes.append(runtime)
+            
+            # compute test performance
+            self.logger.debug(f"finished training on seed {seed} after {int(np.round(runtime))}s. Now computing performance of solution.")
+            score = scorer(naml, X_test, y_test)
+            scores.append(score)
+            self.logger.debug(f"finished test on seed {seed}. Test score for this run is {score}")
+            
+        # check conditions
+        runtime_mean = int(np.round(np.mean(runtimes)))
+        score_mean = np.round(np.mean(scores), 2)
+        self.assertTrue(runtime_mean <= exp_runtime, msg=f"Permitted runtime exceeded. Expected was {exp_runtime}s but true runtime was {runtime_mean}")
+        self.assertTrue(score_mean >= exp_result, msg=f"Returned solution was bad. Expected was at least {exp_result} but true avg score was {score_mean}")
         self.logger.info(f"Test on dataset {openmlid} finished. Mean runtimes was {runtime_mean}s and avg accuracy was {score_mean}")
\ No newline at end of file
